import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _dec, _class, _class2, _temp;

/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import analytics, { configureAnalytics } from './analytics';
import { Provider, inject } from 'mobx-react';
/**
 * Use this component to register your analytics targets.
 *
 * import AnalyticsProvider from 'react-storefront/AnalyticsProvider'
 * import GoogleAnalyticsTarget from 'react-storefront-extensions/GoogleAnalyticsTarget'
 *
 * Example:
 *
 * ```
 *  <AnalyticsProvider
 *    targets={() => [
 *      new GoogleAnalyticsTarget({
 *        trackingID: 'ABC123'
 *      })
 *    ])}
 *  >
 *    <App/>
 *  </AnalyticsProvider>
 * ```
 *
 * Components that are decendents of AnalyticsProvider can use `@inject('analytics')` to get access to
 * an object which can be used to broadcase analytics events to targets:
 *
 * ```
 *  import React, { Component } from 'react'
 *  import Button from '@material-ui/core/Button'
 *  import { inject } from 'mobx-react'
 *
 *  @inject('analytics')
 *  class MyComponent extends Component {
 *
 *    render() {
 *      return (
 *        <Button onClick={this.fireAnalyticsEvent}>Click Me</Button>
 *      )
 *    }
 *
 *    // This will call the someEvent() method on all configured analytics targets.
 *    fireAnalyticsEvent = () => {
 *      const eventData = { foo: 'bar' }
 *      this.props.analytics.fire('someEvent', eventData) // analytics prop is provided by the @inject('analytics') decorator.
 *    }
 *
 *  }
 * ```
 */

var AnalyticsProvider = (_dec = inject(function (_ref) {
  var app = _ref.app,
      history = _ref.history;
  return {
    amp: app && app.amp,
    history: history
  };
}), _dec(_class = (_temp = _class2 =
/*#__PURE__*/
function (_Component) {
  _inherits(AnalyticsProvider, _Component);

  function AnalyticsProvider(props) {
    var _this;

    _classCallCheck(this, AnalyticsProvider);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(AnalyticsProvider).call(this, props)); // Configure analytics for server side AMP rendering

    if (props.targets && props.amp) {
      configureAnalytics.apply(void 0, _toConsumableArray(props.targets(false)));
    }

    return _this;
  }

  _createClass(AnalyticsProvider, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.targets) {
        var targets = this.props.targets();
        configureAnalytics.apply(void 0, _toConsumableArray(targets));
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
          for (var _iterator = targets[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var target = _step.value;

            if (typeof target.setHistory === 'function') {
              target.setHistory(this.props.history);
            }
          }
        } catch (err) {
          _didIteratorError = true;
          _iteratorError = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion && _iterator.return != null) {
              _iterator.return();
            }
          } finally {
            if (_didIteratorError) {
              throw _iteratorError;
            }
          }
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(Provider, {
        analytics: analytics
      }, this.props.children);
    }
  }]);

  return AnalyticsProvider;
}(Component), _defineProperty(_class2, "propTypes", {
  /**
   * Function which should return desired analytics targets to configure.
   */
  targets: PropTypes.func.isRequired
}), _temp)) || _class);
export { AnalyticsProvider as default };
//# sourceMappingURL=AnalyticsProvider.js.map