import _regeneratorRuntime from "@babel/runtime/regenerator";
import "core-js/modules/es6.regexp.search";
import "regenerator-runtime/runtime";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import fetch from 'fetch';
import debounce from 'lodash/debounce';
import { types } from 'mobx-state-tree';
import { fetchLatest, StaleResponseError } from '../fetchLatest'; // Ensures that responses are returned in order and that the previous request is canceled when a new request is sent.

var fetchSearchResults = fetchLatest(fetch);
/**
 * Represents an individual link within a group
 */

export var ResultsModel = types.model('ResultsModel', {
  /**
   * The link text
   */
  text: types.string,

  /**
   * The link's target url
   */
  url: types.string,

  /**
   * A url for a thumbnail image
   */
  thumbnail: types.maybeNull(types.string),

  /**
   * The thumbnail height
   */
  thumbnailHeight: 120,

  /**
   * The thumbnail width
   */
  thumbnailWidth: 120
});
/**
 * Represents a group of links withing the search results
 */

export var ResultsGroupModel = types.model('ResultsGroupModel', {
  /**
   * The caption to display at the top of the group
   */
  caption: types.string,

  /**
   * The list of links to display
   */
  results: types.optional(types.array(ResultsModel), [])
}).views(function (self) {
  return {
    get thumbnails() {
      return self.results.some(function (r) {
        return r.thumbnail != null;
      });
    }

  };
});
/**
 * The base model for site-wide searches.
 */

var SearchModelBase = types.model('SearchModelBase', {
  /**
   * The search phrase entered by the user
   */
  text: '',

  /**
   * The resulting groups
   */
  groups: types.optional(types.array(ResultsGroupModel), []),

  /**
   * True to show the loading spinner
   */
  loading: false,

  /**
   * True to show the search popup
   */
  show: false,

  /**
   * Minimum search text length for submission
   */
  minimumTextLength: 1
}).actions(function (self) {
  return {
    /**
     * Set `true` to show the search popup, `false` to hide.
     * @param {Boolean} show
     */
    toggle: function toggle(show) {
      self.show = show;
    },

    /**
     * Update the search text
     * @param {String} text
     */
    setText: function setText(text) {
      self.text = text;

      if (self.text.trim().length >= self.minimumTextLength) {
        self.loading = true;
        self.submit(text);
      } else {
        self.loading = false;
      }
    },

    /**
     * Set `true` to show the loading spinner, `false` to hide.
     * @param {Boolean} state
     */
    setLoading: function setLoading(loading) {
      self.loading = loading;
    },

    /**
     * Submit the search for the given keyword.  Fetched calls are automatically debounced and serialized so that
     * results are received in order.
     * @param {String} keyword
     */
    submit: debounce(
    /*#__PURE__*/
    function () {
      var _ref = _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee(keyword) {
        var state;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (keyword) {
                  _context.next = 2;
                  break;
                }

                return _context.abrupt("return");

              case 2:
                _context.prev = 2;
                _context.next = 5;
                return fetchSearchResults("/search/suggest.json?q=".concat(encodeURIComponent(keyword))).then(function (res) {
                  return res.json();
                });

              case 5:
                state = _context.sent;
                self.setGroups(state.search.groups);
                self.setLoading(false);
                _context.next = 15;
                break;

              case 10:
                _context.prev = 10;
                _context.t0 = _context["catch"](2);

                if (StaleResponseError.is(_context.t0)) {
                  _context.next = 15;
                  break;
                }

                self.setLoading(false);
                throw _context.t0;

              case 15:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[2, 10]]);
      }));

      return function (_x) {
        return _ref.apply(this, arguments);
      };
    }(), 500),

    /**
     * Set the groups to be displayed
     * @param {ResultsGroupModel[]} groups
     */
    setGroups: function setGroups(groups) {
      self.groups = groups;
    }
  };
});
export default SearchModelBase;
//# sourceMappingURL=SearchModelBase.js.map